==> downloadmanager-1.0.zip: DownloadManager/tab.defaultadmin.files.php <==
<?php

if (!isset($gCms)) exit;
// check for permissions
if (! $this->CheckPermission('Use DownloadManager'))
{
	echo $this->DisplayErrorPage($id, $params, $returnid,$this->Lang('accessdenied'));
	return;
}
$files_categories = $this->GetFileCategories();

//Load files
$entryarray = array();
$query = 'select visible, file_id, name,  ext, description from '.cms_db_prefix() .'module_downloadmanager_files order by name asc';
$dbresult = $db->Execute($query);
$rowclass = 'row1';

$trueicon = $gCms->variables['admintheme']->DisplayImage('icons/system/true.gif', '','','','systemicon');
$falseicon = $gCms->variables['admintheme']->DisplayImage('icons/system/false.gif', '','','','systemicon');
while ($dbresult && $row = $dbresult->FetchRow())
{
	$onerow = new stdClass();
	$onerow->id = $row['file_id'];
//	$onerow->server_name = $row['server_name'];
//	$onerow->ext = $row['ext'];
//	$onerow->size = $row['size'];
//	$onerow->hash = $row['hash'];
	$onerow->description = $row['description'];
//	$onerow->created = $row['created'];
//	$onerow->expires = $row['expires'];
	$onerow->visible = $row['visible']?$trueicon:$falseicon;
	$onerow->name = $this->CreateLink($id, 'editfile', $returnid, $row['name'].($row['ext']!=''?'.'. $row['ext']:''), array('file_id'=>$row['file_id']));
	$onerow->rowclass = $rowclass;
	$onerow->incategories = !array_key_exists((int) $row['file_id'], $files_categories )?0:$files_categories[(int) $row['file_id']]['count'];
//	$onerow->categories = $this->CreateCategoryLinks($id, $returnid, $row['file_id'] , $files_categories );
	$onerow->editlink = $this->CreateLink($id, 'editfile', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/edit.gif', lang('edit'),'','','systemicon'), array('file_id'=>$row['file_id']));
	$onerow->deletelink = $this->CreateLink($id, 'deletefile', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/delete.gif', lang('delete'),'','','systemicon'), array('file_id'=>$row['file_id']), lang('deleteconfirm',$row['name'].($row['ext']!=''?'.'. $row['ext']:'')));
	$entryarray[] = $onerow;
	($rowclass=="row1"?$rowclass="row2":$rowclass="row1");
}

$this->smarty->assign_by_ref('items', $entryarray);
$this->smarty->assign('itemcount', count($entryarray));
$this->smarty->assign('addlink', $this->CreateLink($id, 'addfile', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/newobject.gif', $this->Lang('addfile'),'','','systemicon'), array(), '', false, false, '') .' '. $this->CreateLink($id, 'addfile', $returnid, $this->Lang('addfile'), array(), '', false, false, 'class="pageoptions"'));
$this->smarty->assign('tablevisibleheader', $this->Lang('visiblelabel'));
#Display template
echo $this->ProcessTemplate('listfile.tpl');

?>

==> downloadmanager-1.1.zip: DownloadManager/tab.defaultadmin.files.php <==
<?php

if (!isset($gCms)) exit;
// check for permissions
if (! $this->CheckPermission('Use DownloadManager'))
{
	echo $this->DisplayErrorPage($id, $params, $returnid,$this->Lang('accessdenied'));
	return;
}
$files_categories = $this->GetFileCategories();

//Load files
$entryarray = array();
$query = 'select visible, file_id, alias,name,  ext, description from '.cms_db_prefix() .'module_downloadmanager_files order by name asc';
$dbresult = $db->Execute($query);
$rowclass = 'row1';

$trueicon = $gCms->variables['admintheme']->DisplayImage('icons/system/true.gif', '','','','systemicon');
$falseicon = $gCms->variables['admintheme']->DisplayImage('icons/system/false.gif', '','','','systemicon');
while ($dbresult && $row = $dbresult->FetchRow())
{
	$onerow = new stdClass();
	$onerow->id = $row['file_id'];
//	$onerow->server_name = $row['server_name'];
//	$onerow->ext = $row['ext'];
//	$onerow->size = $row['size'];
//	$onerow->hash = $row['hash'];
	$onerow->description = $row['description'];
//	$onerow->created = $row['created'];
//	$onerow->expires = $row['expires'];
	$onerow->visible = $row['visible']?$trueicon:$falseicon;
	$onerow->name = $this->CreateLink($id, 'editfile', $returnid, $row['name'].($row['ext']!=''?'.'. $row['ext']:''), array('file_id'=>$row['file_id']));
	$onerow->rowclass = $rowclass;
	$onerow->alias = $row['alias'];
	$onerow->changelink = $this->CreateLink($id, 'changefile', $returnid, '<img class="systemicon" src="'.$gCms->config['root_url'].'/modules/DownloadManager/images/icons/transport.png" alt="'. $this->lang('filechange').'" title="'. $this->lang('filechange').'"/>', array('file_id'=>$row['file_id'], 'name'=> base64_encode($row['name']), 'alias'=> base64_encode($row['alias']) ));
	$onerow->incategories = !array_key_exists((int) $row['file_id'], $files_categories )?0:$files_categories[(int) $row['file_id']]['count'];
//	$onerow->categories = $this->CreateCategoryLinks($id, $returnid, $row['file_id'] , $files_categories );
	$onerow->editlink = $this->CreateLink($id, 'editfile', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/edit.gif', lang('edit'),'','','systemicon'), array('file_id'=>$row['file_id']));
	$onerow->deletelink = $this->CreateLink($id, 'deletefile', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/delete.gif', lang('delete'),'','','systemicon'), array('file_id'=>$row['file_id']), lang('deleteconfirm',$row['name'].($row['ext']!=''?'.'. $row['ext']:'')));
	$entryarray[] = $onerow;
	($rowclass=="row1"?$rowclass="row2":$rowclass="row1");
}

$this->smarty->assign_by_ref('items', $entryarray);
$this->smarty->assign('itemcount', count($entryarray));
$this->smarty->assign('addlink', $this->CreateLink($id, 'addfile', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/newobject.gif', $this->Lang('addfile'),'','','systemicon'), array(), '', false, false, '') .' '. $this->CreateLink($id, 'addfile', $returnid, $this->Lang('addfile'), array(), '', false, false, 'class="pageoptions"'));
$this->smarty->assign('tablevisibleheader', $this->Lang('visiblelabel'));
#Display template
echo $this->ProcessTemplate('listfile.tpl');

?>
